@@ -52,7 +52,10 @@ where
     for duration in &backoff {
         match f().await {
             Ok(val) => return Ok(val),
-            Err(_) => tokio::time::sleep(duration).await,
+            Err(_) => {
+                tokio::time::sleep(duration).await;
+                debug!("**** retrying *** ");
+            }
         }
     }
 
@@ -60,7 +63,7 @@ where
 }
 
 fn get_backoff_policy(retries: u8) -> Backoff {
-    let min = Duration::from_secs(2);
+    let min = Duration::from_millis(500);
     let max = Duration::from_secs(30);
     Backoff::new(retries as u32, min, max)
 }
